@@ -3,7 +3,7 @@ from enum import Enum
 from lambda_actor.utils.dateutil import timestamp
 from typing import List
 from dataclasses_json import dataclass_json
-import boto3
+from datetime import datetime
 
 class DriverTriggerStatusType(Enum):
     CONTINUE = "continue"
@@ -146,4 +146,5 @@ class ExecutorResultMessage:
     executor_start_timestamp: str
     retry_count: int
     executor_id: int
-    execute_time: str
\ No newline at end of file
+    execute_time: str
+    timestamp: str = datetime.now().strftime('%Y%m%d%H%M%S')
\ No newline at end of file
